Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KeyMap ¶
type KeyMap struct {
// Navigation
Up key.Binding
Down key.Binding
// Selection
Select key.Binding
// Emacs-style cursor movement
CursorStart key.Binding
CursorEnd key.Binding
CursorBack key.Binding
CursorForward key.Binding
// Emacs-style editing
DeleteWordBack key.Binding
KillLine key.Binding
// Actions
ToggleDelete key.Binding
Rename key.Binding
Create key.Binding
Help key.Binding
// General
Cancel key.Binding
Backspace key.Binding
}
KeyMap contains all key bindings for the TUI
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model represents the state of the Bubble Tea application
func (Model) OutputCommand ¶
OutputCommand returns the command to output on exit
func (Model) ShouldExit ¶
ShouldExit returns whether the TUI should exit
type Styles ¶
type Styles struct {
Title lipgloss.Style
SearchPrefix lipgloss.Style
SearchInput lipgloss.Style
SearchCursor lipgloss.Style
ListItem lipgloss.Style
ListItemSelected lipgloss.Style
ListItemMarked lipgloss.Style
DatePrefix lipgloss.Style
HelpText lipgloss.Style
StatusBar lipgloss.Style
StatusMessage lipgloss.Style
ErrorMessage lipgloss.Style
SuccessMessage lipgloss.Style
Prompt lipgloss.Style
PromptInput lipgloss.Style
Muted lipgloss.Style
GitBranch lipgloss.Style
GitAhead lipgloss.Style
GitBehind lipgloss.Style
GitDirty lipgloss.Style
ColumnHeader lipgloss.Style
}
Styles contains all the lipgloss styles for the TUI
Click to show internal directories.
Click to hide internal directories.